@@ -1,7 +1,7 @@
 # ===========================================================================
 # File: "runit_hubert.R"
 #                        Created: 2012-11-06 20:02:30
-#              Last modification: 2012-11-06 20:02:30
+#              Last modification: 2015-08-31 10:09:41
 # Author: Bernard Desgraupes
 # e-mail: <bdesgraupes@users.sourceforge.net>
 # Unit test file for the R package clusterCrit.
@@ -10,12 +10,13 @@
 
 
 test.hubert <- function() {
-	dataPath <- file.path(.path.package(package="clusterCrit"),"unitTests","data","testsExternal100.Rdata")
+	dataPath <- file.path(path.package(package="clusterCrit"),"unitTests","data","testsExternal100.Rdata")
 	load(file=dataPath, envir=.GlobalEnv)
 	idx <- extCriteria(clus_p2, clus_p3, c("Hubert"))
-	cat(paste("\nShould be =",0.022714141794819,"\n"))
-	cat(paste("\nFound idx =",idx))
-	checkEqualsNumeric(idx[[1]],0.022714141794819)
+	val <- 0.022714141794819
+	cat(paste("\nShould be =",val,"\n"))
+	cat(paste("\nFound idx =",idx,"\n"))
+	checkEqualsNumeric(idx[[1]],val)
 }
 
 
